@@ -1,3 +1,4 @@
+from babel.dates import format_timedelta
 from flask import abort, render_template,request,Response,g
 from wtforms.validators import Regexp,ValidationError
 import urllib,uuid
@@ -98,7 +99,9 @@ def get_common_data(user_uuid,mode):
     else:
         db_domain=Domain.query.filter(Domain.domain==domain).first() or Domain(domain=domain,mode=DomainType.direct,cdn_ip='',show_domains=[])
 
-    
+    if not db_domain:
+        db_domain=Domain(domain=domain,mode=DomainType.direct,show_domains=[])
+        flash(_("This domain does not exist in the panel!" + domain))
 
     if mode =='multi':
         domains=Domain.query.all()
@@ -145,6 +148,7 @@ def get_common_data(user_uuid,mode):
         'usage_current_b':int(user.current_usage_GB*1024*1024*1024),
         'expire_s':int((user.expiry_time-datetime.date(1970, 1, 1)).total_seconds()),
         'expire_days':(user.expiry_time-datetime.date.today()).days,
+        'expire_rel':format_timedelta(user.expiry_time-datetime.date.today(), add_direction=True, locale=hconfig(ConfigEnum.lang)),
         'reset_day':package_mode_dic.get(user.mode,1000)-(datetime.date.today()-user.last_reset_time).days,
         'hconfigs':get_hconfigs(),
         'hdomains':get_hdomains(),
